// This file is part of mzLogger.
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License version 2, as published by the
// Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
// mzLogger. If not, see <http://www.gnu.org/licenses/>.
//
// This work is Copyright (C) 2016 by Josse van der Plaat
//
// Individual portions may be copyright by individual contributors, and are
// included in this collective work with permission of the copyright owners.

#include "verbosity.h"

#include <stdexcept>

Verbosity::V Verbosity::FromString(const std::string& str) {
    V verbosity = Warning;
    int num = -1;
    try {
        num = stoi(str);
    }
    catch (std::invalid_argument ia) { /* Don't care. */ }
    if (num > 0) {
        verbosity = Verbosity::V(num);
    }
    else if (str == "none" || str == "None") {
        verbosity = None;
    }
    else if (str == "error" || str == "Error") {
        verbosity = Error;
    }
    else if (str == "warning" || str == "Warning") {
        verbosity = Warning;
    }
    else if (str == "info" || str == "Info") {
        verbosity = Info;
    }
    else if (str == "debug" || str == "Debug") {
        verbosity = Debug;
    }
    else if (str == "trace" || str == "Trace") {
        verbosity = Trace;
    }
    return verbosity;
}

std::string Verbosity::toString() const {
    std::string result;
    switch (verbosity) {
    case None: {
        result = "None";
    } break;
    case Error: {
        result = "Error";
    } break;
    case Warning: {
        result = "Warning";
    } break;
    case Info: {
        result = "Info";
    } break;
    case Debug: {
        result = "Debug";
    } break;
    case Trace: {
        result = "Trace";
    } break;
    }
    return result;
}

bool operator==(const Verbosity& lhs, const Verbosity& rhs) {
    return lhs.verbosity == rhs.verbosity;
}

bool operator!=(const Verbosity& lhs, const Verbosity& rhs) {
    return !(lhs == rhs);
}

bool operator<(const Verbosity& lhs, const Verbosity& rhs) {
    return lhs.verbosity < rhs.verbosity;
}

bool operator>=(const Verbosity& lhs, const Verbosity& rhs) {
    return !(lhs < rhs);
}

bool operator<=(const Verbosity& lhs, const Verbosity& rhs) {
    return lhs == rhs || lhs < rhs;
}

bool operator>(const Verbosity& lhs, const Verbosity& rhs) {
    return !(lhs <= rhs);
}
